/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.harness;

import java.io.File;

/**
 * Various tools for files and directories manipulation.
 *
 * @author Pavel Tisnovsky
 */
public class FileSystemTools
{
    /**
     * Create directory.
     *
     * @param directoryName
     *            directory which should be created
     */
    public static void createDirectory(String directoryName)
    {
        File directory = new File(directoryName);
        if (directory.isFile())
        {
            System.err.println("Directory " + directoryName
                    + " can not be created because file with the same name already exists!");
            throw new RuntimeException("Can't create work directory (please remove file named " + directoryName + ")");
        }
        if (!directory.exists())
        {
            if (directory.mkdir())
            {
                System.out.println("Warning: cannot create directory " + directory.getAbsolutePath());
            }
        }
    }

    /**
     * Try to delete all files in given directory.
     * 
     * @param directoryName
     *            directory which content should be deleted
     */
    public static void eraseDirectory(String directoryName)
    {
        File directory = new File(directoryName);
        for (String fileName : directory.list())
        {
            File fileToDelete = new File(directory, fileName);
            // try to delete work file
            if (!fileToDelete.delete())
            {
                System.out.println("Warning: cannot delete file " + fileToDelete.getAbsolutePath());
            }
        }
    }

    public static String constructTestDirectoryName(String baseDirectory, String selectedTestName)
    {
        return new File(baseDirectory, selectedTestName).getAbsolutePath();
    }

}
